@@ -166,6 +166,8 @@ RDO_PKG_MAP = [
     SingleRule('google-api-python-client', 'python-google-api-client',
                py3pkg='python3-google-api-client'),
     SingleRule('GitPython', 'GitPython', py3pkg='python3-GitPython'),
+    SingleRule('heat-agents', 'openstack-heat-agents',
+               py3pkg='openstack-heat-agents'),
     SingleRule('pyOpenSSL', 'pyOpenSSL', py3pkg='python3-pyOpenSSL'),
     SingleRule('IPy', 'python-IPy', py3pkg='python-IPy-python3'),
     SingleRule('pycrypto', 'python-crypto', py3pkg='python3-crypto'),
@@ -200,6 +202,7 @@ RDO_PKG_MAP = [
     SingleRule('xattr', 'pyxattr', py3pkg='python3-pyxattr'),
     SingleRule('XStatic-term.js', 'python-XStatic-termjs',
                py3pkg='python3-XStatic-termjs'),
+    SingleRule('heat-cfntools', 'heat-cfntools'),
     SingleRule('horizon', 'openstack-dashboard'),
     SingleRule('networking-vsphere', 'openstack-neutron-vsphere'),
     SingleRule('m2crypto', 'm2crypto'),
@@ -288,6 +291,8 @@ SUSE_PKG_MAP = [
     SingleRule('designate-dashboard', 'openstack-horizon-plugin-designate-ui'),
     SingleRule('freezer-web-ui', 'openstack-horizon-plugin-freezer-ui'),
     SingleRule('group-based-policy-ui', 'openstack-horizon-plugin-gbp-ui'),
+    SingleRule('heat-agents', 'openstack-heat-agents',
+               py3pkg='openstack-heat-agents'),
     SingleRule('horizon', 'openstack-dashboard'),
     SingleRule('ironic-ui', 'openstack-horizon-plugin-ironic-ui'),
     SingleRule('magnum-ui', 'openstack-horizon-plugin-magnum-ui'),
